package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````_"0```````!``````````&@!`0``
M`````@```$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````&BA````````:*$`````````
M``$```````$````&````&/L````````8^P$``````!C[`0``````:`4`````
M``#`!0```````````0```````@````8````H^P```````"C[`0``````*/L!
M`````````@`````````"````````"`````````!0Y71D!````*R;````````
MK)L```````"LFP```````.0`````````Y``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````8^P```````!C[`0``````&/L!``````#H!```````
M`.@$`````````0`````````O;&EB+VQD+6UU<VPM<&]W97)P8S8T;&4N<V\N
M,0```!$```!@````!`````@````@$!``!4`$@"@`$`2`A@"$@B$```D`!`F(
M@!A!N@0""`````!@````9````&@```!I````;P```'````!Q`````````',`
M``!T`````````'4```!V````>```````````````:G^:?.K3[P[.WD<M;\7?
M'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'Q@&[XY)\
M5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IK&IY0H^#[20``````
M```````````````````````````````#``<`:!L`````````````````````
M```#`!(````"`````````````````!H#```"``@`#%D`````````````````
M`"<#```"``@`"%D``````````````````#0#```"``@`!%D`````````````
M`````$$#```"``@``%D``````````````````$X#```"``@`^%@`````````
M`````````%L#```"``@`;%D``````````````````&@#```"``@`<%D`````
M`````````````'4#```"``@`_%@``````````````````*D#```"``@`'%D`
M`````````````````+8#```"``@`&%D``````````````````,,#```"``@`
M$%D``````````````````-`#```"``@`%%D```````````````````0$```"
M``@`(%D``````````````````!$$```"``@`)%D``````````````````!X$
M```"``@`5%D``````````````````"L$```"``@`.%D`````````````````
M`#@$```"``@`-%D``````````````````$4$```"``@`0%D`````````````
M`````%($```"``@`/%D``````````````````%\$```"``@`,%D`````````
M`````````)L$```"``@`1%D``````````````````+($```"``@`2%D`````
M`````````````+\$```"``@`3%D``````````````````,P$```"``@`4%D`
M``````````````````$````28`````````````````````````D````1````
M`````````````````````+L!```1`````````````````````````$0!```2
M8````````````````````````!`````28````````````````````````)0!
M```28````````````````````````!@````28```````````````````````
M`,@!```28````````````````````````*`!```28```````````````````
M`````!\````@`````````````````````````,L"```A````````````````
M`````````#<````28````````````````````````#T````2````````````
M`````````````$0````2`````````````````````````(("```28```````
M`````````````````*`"```28````````````````````````$L````2````
M`````````````````````.,!```28````````````````````````%(````2
M8````````````````````````&D"```28````````````````````````%D`
M```28````````````````````````&$````2````````````````````````
M`'L"```28````````````````````````&D````28```````````````````
M`````%("```28````````````````````````'$````28```````````````
M`````````'<````28````````````````````````(`````@````````````
M`````````````)("```28````````````````````````)P````28```````
M`````````````````*$````28````````````````````````&$!```6````
M`````````````````````'`"```28````````````````````````!`"```2
M8````````````````````````*@````28`````````````````````````("
M```28````````````````````````!$#```28```````````````````````
M`,H"```1`````````````````````````#0"```28```````````````````
M`````+<"```28````````````````````````,P"```1````````````````
M`````````*\````28````````````````````````%(!```28```````````
M`````````````+@````B`````````````````````````,<````@````````
M`````````````````-T````28````````````````````````*\"```28```
M`````````````````````"`"```28````````````````````````.(````@
M`````````````````````````%T"```28````````````````````````/P`
M```28````````````````````````(4!```28```````````````````````
M``$!```28````````````````````````$("```28```````````````````
M`````'0!```28`````````````````````````<!```2````````````````
M`````````!@!```28````````````````````````-X!```28```````````
M`````````````'(````28````````````````````````.\!```28```````
M`````````````````"D"```28````````````````````````)D"```28```
M`````````````````````(H"```28````````````````````````!X!```2
M`````````````````````````-D!```28````````````````````````"4!
M```2`````````````````````````"P!```2````````````````````````
M`,D"```A`````````````````````````#T!```2````````````````````
M`````,0"```28`@`P"(````````\`@```````+4!```28`D`H%H````````0
M`````````.\#```28`@`Y#8````````H!@```````#<%```28`@`:#\`````
M``"8`````````)@#```28`@`/#`````````8`````````/4$```28`<`:!L`
M```````0`````````'H$```28`@`##T```````!<`@```````!L%```28`@`
M5#````````!(`@```````.8$```0`!,`@``"`````````````````-T#```2
M8`@`(#8```````#$`````````/P#```28`@`D"X```````!@`````````&P$
M```28`@`;#4```````!H`````````)`$```28`@`(%8````````T`0``````
M`-D$```28`@`G#(```````!4`````````#(%```0`!,`V``"````````````
M`````/8"```28`@`*"4```````!<`````````/L$```28`@`\#(````````\
M`0```````*@$```1`!(`>``"```````(`````````!0%```0`!(`@``"````
M`````````````.L$```2``@`_"0``````````````````/($```28`@`C%4`
M``````"4`````````/\"```28`@`U#4```````!,`````````((#```28`@`
M7"\```````#@`````````"@%```28`@`5%<```````"D`0````````<%```2
M8`@`+#0```````!``0````````!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C
M8V5S<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R
M8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`'-T<G)C:'(`;'-T
M870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`
M<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7V-X85]F:6YA;&EZ90!?7W)E9VES
M=&5R7V9R86UE7VEN9F\`97AI=`!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`')E860`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!M96UC<'D`<W1R
M;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`<W1R8W!Y`')E861D:7(`<W!R:6YT
M9@!S=')D=7``<W1R=&]K`'!T:')E861?871F;W)K`&9P<FEN=&8`7U]L:6)C
M7W-T87)T7VUA:6X`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UP
M<&,V-&QE+G-O+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`7W-A=F5G<'(P7S(U`%]S879E9W!R,%\R-`!?<V%V96=P<C!?,C,`7W-A
M=F5G<'(P7S(R`%]S879E9W!R,%\R,`!?<F5S=&=P<C!?,S``7W)E<W1G<'(P
M7S,Q`%]S879E9W!R,%\R,0!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U
M<G)E;G1?97AE8P!?<V%V96=P<C!?,CD`7W-A=F5G<'(P7S(X`%]S879E9W!R
M,%\R-@!?<V%V96=P<C!?,C<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP
M9&ER`'AS7VEN:70`7W-A=F5G<'(P7S,P`%]S879E9W!R,%\S,0!?<F5S=&=P
M<C!?,CD`7W)E<W1G<'(P7S(R`%]R97-T9W!R,%\R,0!?<F5S=&=P<C!?,C0`
M7W)E<W1G<'(P7S(S`%]R97-T9W!R,%\R,`!P87)?96YV7V-L96%N`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`%]R97-T9W!R,%\R-0!M>5]P
M87)?<&P`7W)E<W1G<'(P7S(V`%]R97-T9W!R,%\R-P!?<F5S=&=P<C!?,C@`
M<&%R7V)A<V5N86UE`%]?8G-S7W-T87)T`'-H85]I;FET`'!A<E]D:7)N86UE
M`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?
M96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%
M```````````8^P$``````!8`````````\"8````````@^P$``````!8`````
M````8"8```````````(``````!8````````````"```````8``(``````!8`
M````````;ET````````@``(``````!8`````````R5H````````P``(`````
M`!8`````````JEL````````X``(``````!8`````````HUL```````!```(`
M`````!8`````````8ET```````!(``(``````!8`````````P%L```````!0
M``(``````!8`````````:ET```````!@``(``````!8`````````5%T`````
M``!H``(``````!8`````````65T```````!X``(``````!8`````````<UT`
M```````(_P$``````"8````V```````````````0_P$``````"8```!+````
M```````````8_P$``````"8```!&```````````````@_P$``````"8````D
M```````````````H_P$``````"8```!'```````````````P_P$``````"8`
M``!#```````````````X_P$``````"8```!0``````````````!`_P$`````
M`"8````<``````````````!(_P$``````"8```!6``````````````!0_P$`
M`````"8```!1``````````````!8_P$``````"8````=``````````````!@
M_P$``````$D````Z```````````````X_0$``````!4````;````````````
M``!`_0$``````!4````>``````````````!(_0$``````!4````?````````
M``````!0_0$``````!4````@``````````````!8_0$``````!4````A````
M``````````!@_0$``````!4````B``````````````!H_0$``````!4````C
M``````````````!P_0$``````!4````D``````````````!X_0$``````!4`
M```F``````````````"`_0$``````!4````G``````````````"(_0$`````
M`!4````H``````````````"0_0$``````!4````I``````````````"8_0$`
M`````!4````J``````````````"@_0$``````!4````K``````````````"H
M_0$``````!4````L``````````````"P_0$``````!4````M````````````
M``"X_0$``````!4````N``````````````#`_0$``````!4````O````````
M``````#(_0$``````!4````P``````````````#0_0$``````!4````Q````
M``````````#8_0$``````!4````R``````````````#@_0$``````!4````S
M``````````````#H_0$``````!4````T``````````````#P_0$``````!4`
M```U``````````````#X_0$``````!4````W````````````````_@$`````
M`!4````X```````````````(_@$``````!4````Y```````````````0_@$`
M`````!4````[```````````````8_@$``````!4````\```````````````@
M_@$``````!4````]```````````````H_@$``````!4````^````````````
M```P_@$``````!4````_```````````````X_@$``````!4```!!````````
M``````!`_@$``````!4```!"``````````````!(_@$``````!4```!$````
M``````````!0_@$``````!4```!%``````````````!8_@$``````!4```!&
M``````````````!@_@$``````!4```!'``````````````!H_@$``````!4`
M``!(``````````````!P_@$``````!4```!)``````````````!X_@$`````
M`!4```!*``````````````"`_@$``````!4```!,``````````````"(_@$`
M`````!4```!-``````````````"0_@$``````!4```!.``````````````"8
M_@$``````!4```!/``````````````"@_@$``````!4```!2````````````
M``"H_@$``````!4```!3``````````````"P_@$``````!4```!4````````
M``````"X_@$``````!4```!5``````````````#`_@$``````!4```!7````
M``````````#(_@$``````!4```!8``````````````#0_@$``````!4```!9
M``````````````#8_@$``````!4```!:``````````````#@_@$``````!4`
M``!;``````````````#H_@$``````!4```!<``````````````#P_@$`````
M`!4```!=``````````````#X_@$``````!4```!?```````````````"`$P\
MF&-".*8""'P0``'XX?\A^"``(3@0``'HI@,(?"``@$X`````````````````
M`````````!@`0?C__X(]D'Z,Z:8#B7T@!(!.````````````````&`!!^/__
M@CUP?XSII@.)?2`$@$X````````````````8`$'X__^"/=A_C.FF`XE](`2`
M3@```````````````!@`0?C__X(]B'^,Z:8#B7T@!(!.````````````````
M&`!!^/__@CTH?XSII@.)?2`$@$X````````````````8`$'X__^"/4A^C.FF
M`XE](`2`3@```````````````!@`0?C__X(]0'Z,Z:8#B7T@!(!.````````
M````````&`!!^/__@CU8?HSII@.)?2`$@$X````````````````8`$'X__^"
M/;!_C.FF`XE](`2`3@```````````````!@`0?C__X(]R'Z,Z:8#B7T@!(!.
M````````````````&`!!^/__@CV`?XSII@.)?2`$@$X````````````````8
M`$'X__^"/2!_C.FF`XE](`2`3@```````````````!@`0?C__X(]@'Z,Z:8#
MB7T@!(!.````````````````&`!!^/__@CW0?HSII@.)?2`$@$X`````````
M```````8`$'X__^"/:A^C.FF`XE](`2`3@```````````````!@`0?C__X(]
M8'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CT8?XSII@.)?2`$@$X`
M```````````````8`$'X__^"/;A_C.FF`XE](`2`3@```````````````!@`
M0?C__X(]4'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CUH?HSII@.)
M?2`$@$X````````````````8`$'X__^"/6!_C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]Z'^,Z:8#B7T@!(!.````````````````&`!!^/__@CT`
M?XSII@.)?2`$@$X````````````````8`$'X__^"/0A_C.FF`XE](`2`3@``
M`````````````!@`0?C__X(],'^,Z:8#B7T@!(!.````````````````&`!!
M^/__@CTX?XSII@.)?2`$@$X````````````````8`$'X__^"/?!^C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]H'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CWX?HSII@.)?2`$@$X````````````````8`$'X__^"/:!^
MC.FF`XE](`2`3@```````````````!@`0?C__X(]Z'Z,Z:8#B7T@!(!.````
M````````````&`!!^/__@CW0?XSII@.)?2`$@$X````````````````8`$'X
M__^"/9!_C.FF`XE](`2`3@```````````````!@`0?C__X(]$'^,Z:8#B7T@
M!(!.````````````````&`!!^/__@CU(?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/?!_C.FF`XE](`2`3@```````````````!@`0?C__X(]6'^,
MZ:8#B7T@!(!.````````````````&`!!^/__@CU`?XSII@.)?2`$@$X`````
M```````````8`$'X__^"/9A^C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]^'^,Z:8#B7T@!(!.````````````````&`!!^/__@CV8?XSII@.)?2`$
M@$X````````````````8`$'X__^"/5!_C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]R'^,Z:8#B7T@!(!.````````````````&`!!^/__@CW@?XSI
MI@.)?2`$@$X````````````````8`$'X__^"/;A^C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]<'Z,Z:8#B7T@!(!.````````````````&`!!^/__
M@CTX?HSII@.)?2`$@$X````````````````8`$'X__^"/;!^C.FF`XE](`2`
M3@```````````````!@`0?C__X(]P'^,Z:8#B7T@!(!.````````````````
M&`!!^/__@CW@?HSII@.)?2`$@$X````````````````8`$'X__^"/:A_C.FF
M`XE](`2`3@```````````````!@`0?C__X(]>'^,Z:8#B7T@!(!.````````
M````````&`!!^/__@CUH?XSII@.)?2`$@$X````````````````8`$'X__^"
M/=A^C.FF`XE](`2`3@```````````````!@`0?C__X(]>'Z,Z:8#B7T@!(!.
M````````````````&`!!^/__@CW`?HSII@.)?2`$@$X````````````````8
M`$'X__^"/8A^C.FF`XE](`2`3@````````````````(`3#Q`7$(XI@((?/C_
MX?L0``'X<?\A^'``@?AH`*'X<`"!.&@`H3A\`&&0?`!A.-']_TL8`$'H````
M8$B`HN@```!@4(!BZ'@KI'Q5_?]+&`!!Z````&!8@"+I``#IBP``'RQ$`()`
MF?S_2Q@`0>@```!@```C+-"!8O@0`()``0!@.-W^_TL8`$'H5?S_2Q@`0>@`
M``!@8(`BZ11J*7T``"GIIPOIFP```&!\`&&`8(`BZ11J*7T#`.,[!`!C.```
M2>FT!V-\)!]C>/H%*HD#`"EA^@4JF4GY_TL8`$'H<`#AZ````&!\`$&!````
M.<"!8OAX&V9\```GZ0``"BP``"/Y_O\B/4[>*3D(`"/Y````8'B!(ND0`"/Y
M_O\B/5'>*3D8`"/Y__\J.2``*7D!`"DY"`"!00$`(#D!`"DL!`!(.;0'2GT!
M``@Y)!]*>?__*3G,`()````@.0```&#0@6+H_O^"/+0'Y7\``.`X*E$F??"O
MA#B)_?]+&`!!Z````RQX&W]\&`""0````&#0@6+HK?W_2Q@`0>AX&W]\````
M8-"!8NA9^O]+&`!!Z/[_8CQ=W&,XI0,`2```(RP\`()`````8,B!(ND``"DL
M&`""0/[_8CP2W&,X@0,`2````&#(@6+X````8,B!8N@``",L"`""0;D:`$@`
M``!@T(%BZ#W\_TL8`$'HE??_2Q@`0>B0`"$XM`?C?Y0T`$@D'P5Y*BBG?"I1
MIGP0__]+``````````&``0```@!,/`1:0C@H`(R`%&*$?'@+(WSD!B%X````
M..'_`?BF`PA\$0``2"S6`0`"`$P\V%E".*8""'P(`*,X_O_B/*#;YSC^_\(\
M:)S&.`(`@^C^_V(\P*-C.````#D0``'XX?\A^.'Z_TL8`$'H(``A.!```>BF
M`PA\(`"`3@`````````!@````````&````!@````8`(`3#QP64(X````8```
M`&"`@6(X@($B.0`8*7P@`()-````8`B`@ND``"PL(`""3:8""'RF`XE]$``!
M^.'_(?@8`$'X(02`3A@`0>@@`"$X$``!Z*8#"'P@`(!.``!"8`(`3#P064(X
M````8````&"`@6(X@(&".%`@@WQT'H1\=`Z$?)4!A'P@`()-````8!"`@ND`
M`"PL(`""3:8""'RF`XE]$``!^.'_(?@8`$'X(02`3A@`0>@@`"$X$``!Z*8#
M"'P@`(!.````8```0F`"`$P\H%A".````&"`@2*)```)+"``@DRF`@A\````
M8!B`(ND``"DL$``!^.'_(?@4`()!````8`"!8NB%^?]+&`!!Z/7^_TL```!@
M((`BZ0``*2P4`()!_O]B/+P=8SB!^O]+&`!!Z"``(3@!`"`Y````8!```>B`
M@2*9I@,(?"``@$X```!@````8```0F`"`$P\$%A".````&`H@"+I```I+#P`
M@D&F`@A\````8/[_8CR(@8(XO!UC.!```?CA_R'X_?;_2Q@`0>@@`"$X$``!
MZ*8#"'S`_O]+``!"8+C^_TL"`$P\O%=".*8""'S!,0!(>1M\?+'_(?@``,`[
M)`""00```&`P@"+I``#`.W@CFGQXXX5_``"IZP``/2P<`()`4``A.'CSPW^\
M,0!(/0`)+!0`@D$!`*4X```EB0``"2SL_X)`4"B\?'CKNW^T![]\``#;ZP``
M/BS(_X)!>/OE?WCCA']X\\-_]?3_2Q@`0>@```,L*`""0*[X/GT]``DL'`""
M0%#8O7\!`/\[=!Z]?Q3ZWG\``+J3B/__2P@`>SNP__]+``````````&`!@``
M`@!,/.Q60CBF`@A\$``!^)'_(?AD`($X\(\MZ6@`(?D``"`Y%?__2V@`0>GP
MCRWI>4I*?0``(#D,`()!L??_2Q@`0>AP`"$X$``!Z*8#"'P@`(!.````````
M``&``````@!,/(Q60CBF`@A\\/_!^_C_X?MX&W]\$``!^('_(?CPCRWI:``A
M^0``(#ED`,$[>//$?WC[XW^A_O]+```C+"``@D!H`$'I\(\MZ7E*2GT``"`Y
M/`""037W_TL8`$'H9@!!Z0```&`P@"+I```IZ20?2GGX_THY%%(I?1``2>D`
M`"HL"0!)^?3_@D"D__]+@``A.&0P`$@``````````8`"```"`$P\Z%5".*8"
M"'SX_^'[>!M_?!```?@Q_R'X*`"!./"/+>FX`"'Y```@.1WV_TL8`$'H```@
M.0```RP\`()`0`!!@28$2E4`0`HH%`""0?__2&UX&VE\`*`(+!P`@D`"`(`X
M>/OC?P'S_TL8`$'H-`!I?'[9*56T!R-]N`!!Z?"/+>EY2DI]```@.0P`@D%9
M]O]+&`!!Z-``(3B\+P!(``````````&``0```@!,/#Q50CBF`@A\02\`2-'^
M(?AY&WY\\(\MZ?@`(?D``"`Y7`""00``/HD```DL4`""06GW_TL8`$'H>1M\
M?$``@D'^_V(__O]"/\G;>SO(VUH[>..#?X7Q_TL8`$'H>1M_?#@`@D!XXX-_
ML?3_2Q@`0>AX\\-_9?;_2Q@`0>CX`$'I\(\MZ7E*2GT``"`YV`""0:GU_TL8
M`$'H$P#_.WC;9']X^^-_-?C_2Q@`0>@```,LH/^"07C31']X^^-_'?C_2Q@`
M0>@```,LB/^"07CSPW^I\_]+&`!!Z'@;?7QX^^-_F?/_2Q@`0>@4&GU\`@!C
M.+0'8WQE]O]+&`!!Z/[_@CQX^^9_>//%?\O;A#AX&WU\J?3_2Q@`0>AH`($X
M>.NC?]GR_TL8`$'H__\#+'CKHW\H`()!@``A@28$*54`0`DL&`""0,'^_TMX
MZZ-_C?'_2Q@`0>C\_O]+8?;_2Q@`0>CH__]+,`$A.!@N`$@``````````8`&
M```"`$P\P%-".*8""'P!`$`]*`!*80(`H#@``(`XO2T`2/[_`#QX&WU\L/\`
M8`$`@#\(`)QC:@$A?!0*2GT@`.$[\(\MZ0``*OD``"`YU?;_2Q@`0>C__\,[
M=(;>?Y0!WG_D@]Y[```^+`P`@$#__V`X@```2```H#AX\\1_>.NC?Z'V_TL8
M`$'H>..%?WC[Y']XZZ-_+?#_2Q@`0>BT!VE\!P`I*!0`@4#X_RDY%$H_?4#X
M*7P,`(!`___>/ZC__TL```!@*$P`?0B!0CDH5$!]$$!*??0#2GT000A]>$-*
M?0``"BPT`()`4$A_?!3R8WP!`"`]*``I810**7T``$GI\(\MZ7E*2GT``"`Y
M%`""0;'S_TL8`$'H__\I.93__TL``"'H["P`2``````````!@`0```(`3#R,
M4D(XI@((?(TL`$A1_R'X>!M_?'@CGGSPCRWI:``A^0``(#D``"2)/0`)+`@`
M@D`!`,0[>//#?Y'Q_TL8`$'H9`"!.'@;?7QX^^-_B?K_2WD;?'Q,`()!<?'_
M2Q@`0>A`&#U\N`"!00``0#FN4#Y]KE$\?3X&*54!`$HY```)+.S_@D!H`$'I
M\(\MZ7E*2GT``"`Y<`&"0?'R_TL8`$'H````8#"`8NL``"`Y```[Z_C_&3EX
M2SQ]`0`I.20?*GDJ4$A]```J+.S_@D````!@N($B@0(`G#BT!X1\)!^$>```
M"2S<`()!>,LC?]WN_TL8`$'H```C+```>_B(_X)!`0`\.0``6^D````Y9`"!
MD[0'*7TD'REY*DD*?7C[Z7\``$F)```*+`P`@D$]``HLS`""0&8`@>L```!@
M,(!BZU!(/WT"`'TXM`<I?10::7P``%OK5?/_2Q@`0>@D'YQ[```C+"KA>GP<
M_X)!```[Z?___SLJX"E]`0!?C7A+*'T!`"DY__])F?\`2G$,`()!/0`*+.3_
M@D`]`$`Y``!(F0```#FN0%Y]KD%)?3X&2E4!``@Y```*+.S_@D#(_O]+`0`@
M.0```&!X(X-\N($BD=GR_TL8`$'H>1MZ?*C^@D&T!X5_>,LD?R0?I7@=]/]+
M&`!!Z```6_L(__]+`0`I.2#__TNP`"$XQ"H`2``````````!@`<```(`3#QP
M4$(XI@((?````&````!@.("BZ&"`(NG^_\(\%&HI??[_@CR8',8XT=N$.!``
M`?CA_R'X``!IZ-7R_TL8`$'H(``A.!```>BF`PA\(`"`3@`````````!@```
M``(`3#P04$(XI@((?/C_X?L```!@8(#BZQ1J_W\0``'XT?\A^```?^B!__]+
M``!_Z/[_XCS^_Z(\3=[G./[_@CP````Y>#OF?`R^I3CMVX0X0>[_2Q@`0>@P
M`"$X)"H`2``````````!@`$```(`3#RD3T(XI@((?+4I`$AAWR'X\(\MZ7@@
M(?D``"`YI>W_2Q@`0>AH`.$[_O_"//[_@CQX&V5\`MS&.`;<A#AX^^-_<!"A
M.]WO_TL8`$'H`!"@.'CKI']X^^-_*?#_2Q@`0>@```,L(`"`07@;?WP!`&,X
MM`=C?$WQ_TL8`$'H>1M^?"0`@D```,`[>"!!Z?"/+>EY2DI]```@.2P`@D$%
M\/]+&`!!Z+0'_W]XZZ1_>/OE?]'K_TL8`$'H```@.:[Y/GW(__]+H"`A.'CS
MPW\H*0!(``````````&``P```@!,/,1.0C@@__]+`````````````````@!,
M/*Q.0CBF`@A\)H!P?0@`89&1*`!(H>XA^'@;?GS^_V(\$MQC.'@CGWSPCRWI
M^!`A^0``(#F1]_]++P"`.'@;>WQX\\-_9>S_2Q@`0>@``",L,`""0?[_8CQX
M\\1_&]QC.,7[_TOX$$'I\(\MZ7E*2GT``"`YL`&"03'O_TL8`$'H>/OC?_[_
M0C]![O]+&`!!Z"C<6CO^_R(_>--$?_[_XC[I[_]+&`!!Z/[_PCX``(`Z```[
M+LG;.3MX&W]\````.RK<]SK[W-8Z^`"!.V@`H3H`@)1B```_+'S_@D$``#^)
M```)+`@`@D!XRS]_'`"207C[Y']XVV-_4?'_2Q@`0>@```,L"`&"07C[XW_=
M[/]+&`!!Z!0:/WW__T,Y__\I.112'WU`2#]\>!MJ?`P`@4'__S\L"`""0`$`
M0#D!`"HL__]*.1``@D$``"B)+P`)++``@D%X^^-_D>S_2Q@`0>AX&WU\>//#
M?X'L_TL8`$'H%!J]?P$`O3O_#STHV/Z!07CSQW]XN^9^>/OE?WBSQ'YXXX-_
ME>W_2Q@`0>AXJZ1^>..#?\7K_TL8`$'H```#+%P`@D"``"&!)@0I50"@"7Q,
M`()``0"`.'CC@W]=ZO]+&`!!Z````RPT`()`_O]B/'CCA'\;W&,X/?K_2WCC
M@W_9[/]+&`!!Z'@;?GQH_O]+```(F___"#DT__]+>--$?P``8#AU[O]+&`!!
MZ'@;?WRT_O]+8!$A.'CSPW\(`&&!((%P?:0F`$@``````````X`,```"`$P\
M9$Q".*8""'SX_^'[+P"`.'@;?WP0``'XT?\A^(7O_TL8`$'H```C+`@`@D$!
M`.,[>/OC?TWL_TL8`$'H,``A.)`F`$@``````````8`!```"`$P\$$Q".*8"
M"'SP_\'[^/_A^WD;?GP0``'XP>\A^/"/+>DH$"'Y```@.1``@D$``#Z)```)
M+#``@D#^_V(\R=MC..WK_TL8`$'H*!!!Z?"/+>EY2DI]```@.<P`@D&Q[/]+
M&`!!Z.GJ_TL8`$'H`0`C.0``8#@`$"DHT/^!02@`X3MX\\1_>/OC?\7I_TL8
M`$'H>/OC?[GJ_TL8`$'H``#@./__(SDP$`,Y%$I??7@;:7P4"FA\]^]C.$`8
M/WP0`(%!,!`!.0<0*"P(`()``0`@.0$`*2S__RDY$`""00``"HDO``@L-`""
M02\`@#AX^^-_7>[_2Q@`0>@``",L//^"04#X(WP,`(%````@.0``(YEX^^-_
M+/__2P``ZIC__THYL/__2T`0(3A0)0!(``````````&``@```@!,/-1*0CBF
M`@A\_O]B/"S<8SC9)`!(@?\A^/[_XC_^_Z(_3=S_.Q+<O3O^_\(__O^"/VG<
MWCMSW)P[%?3_2_[_8CPUW&,X"?3_2_[_8CP]W&,X_?/_2_[_8CQ&W&,X\?/_
M2WC[XW_I\_]+_O]B/%W<8SC=\_]+>.NC?]7S_TMX\\-_S?/_2WCC@W_%\_]+
M_O]B/'W<8SBY\_]+_O]B/!O<8SBM\_]+_O]B/(?<8SA!\_]+>1MD?`P`@D%X
MXX-_D??_2_[_8CR8W&,X)?/_2WD;9'P0`()!_O]B/*K<8SAQ]_]+_O]B/+7<
M8S@%\_]+>1MD?"0`@D%XZZ-_5??_2_[_@CQX^^-_UMR$.$7W_TN``"$X$"0`
M2/[_8CS%W&,XT?+_2WD;9'S8_X)!>//#?\S__TL``````````8`$```"`$P\
ME$E".*8""'S^_V(\:=QC.!```?BA_R'XE?+_2P``0#D``",L(`""00``(XD`
M``DL%`""03``*6DT`"E]?MDI50$`*FE@`"$XM`=#?1```>BF`PA\(`"`3@``
M```````!@`````(`3#PL24(XI@((?!```?CA_R'XF>K_2Q@`0>BQZ/]+&`!!
MZ```(RP(`()!``!CZ"``(3@0``'HI@,(?"``@$X``````````8`````"`$P\
MX$A".*8""'SM(@!(@?\A^/[_@C]X&W]\V-R<.WCC@W_9\?]+>/OD?WD;?GP0
M`()!```^B0``"2P4`()`>..#?QGV_TN``"$XY"(`2!'H_TL8`$'H```C+.S_
M@D!X^^-_O>?_2Q@`0>AX&WU\>//#?ZWG_TL8`$'H%!I]?`(`8SA]ZO]+&`!!
MZ/[_PCS^_X(\^]R$.'CSQW]X&WU\*-S&.'C[Y7^YZ/]+&`!!Z'CKI'^,__]+
M``````````&`!````@!,/!Q(0CBF`@A\$`!`.1$B`$@A_B'X_O^"/W@;>WP2
MW)P[>..#?_"/+>F(`2'Y```@.0```&`(@2(YD`$!.9A6"7S0_D`YF%<(?```
M`&`H@4+I<`!!^2@`0#F85FE].`!`.9A6B7U(`$`YF%8)?`#_0#F85VA]$/]`
M.9A7B'T@_T`YF%<(?%@`0#F85@E\Z/X@.9A/"'P```!@<($BZ8@`(?F5\/]+
M>1M_?$``@D$``#^)```)+#0`@D&)_O]+>/OC?WGG_TL8`$'H>!M_?(@!0>GP
MCRWI>4I*?0``(#DP!8)!.>C_2Q@`0>@-_O]+<`#!.WD;?WR4`8)!>/OC?_[_
MHC]9YO]+&`!!Z/___SOOW+T[I`]C>`$`8S@AZ?]+&`!!Z'@;>GQX&WY\`0"_
MC```!2QP`8)`B`#!.PD`_NL``#\L/`""07C[XW_M[_]+>1M_?.C_@D$``#^)
M```)+-S_@D'9\/]+```#+-#_@D%X^^-_R>;_2Q@`0>AX&W]\6`"A.P``/RP<
M`()`"0#=ZP``/BQ0`8)!```^B0``"2P@`8)`>/OC?_[_(C^QY?]+&`!!Z"K<
M.3MX&WY\>--#?YWE_TL8`$'H%!K>?P0$WCNT!]Y_>//#?V7H_TL8`$'H_O_B
M//[_@CQXTTA_]-SG.'C+)G]X^^5_^=R$.'@;?7R=YO]+&`!!Z,`!@#AXZZ-_
M[>C_2Q@`0>C__P,LT`""0/WE_TL8`$'H``#C@!$`!RR\`()!````8$"`(ND`
M`+OH_O^"/+0'YWQXZZ9_`MV$.```:>B)XO]+&`!!Z```X#MP_O]+U>[_2WD;
M:7P@`()!```IB0``"2P4`()!P>7_2Q@`0>AY&W]\=/Z"0`D`?N@``",LT/^"
M0/[_XC_HW/\[7/[_2WCSPW^T!Z5\>.ND?P(`WCOIY?]+&`!!Z'#^_TMX\\-_
M>>__2P```RS`_H)!>//#?VGE_TL8`$'H>!M_?*3^_TL``.`[O/[_2\``@3AX
MZZ-_B>7_2Q@`0>@```,L>!MX?!0`@D#8`"&!)@0I50!`"2PL`()!````8$"`
M(ND``+OH_O^"/'CKIG\]W80X``!IZ*GA_TL8`$'H(/__2]P`X8-9YO]+&`!!
MZ``8'WS(_X)`V``A@?X%*57``0DLN/^"0'CSPW_5YO]+&`!!Z'@;?WS^_V(\
MX]QC.+WM_TMY&V1\P`&"0```6^MXTT-_S>/_2Q@`0>@#``,L>!M^?(@`@4"T
M!V-\_O^"//S_8SB0W80X%!IZ?`7H_TL8`$'H```#+&0`@D`$`!XL&`""0?O_
MWCNT!]Y_KO`Z?2\`"2Q(`()`"`#;ZP``/BP\`()!>//#?VGC_TL8`$'H`P`C
M*"@`@4#\_V,X_O^"/)7=A#@4&GY\J>?_2Q@`0>@```,L"`""0'CSVG]I^O]+
M_O_B/DW>]SH```,L,`&"0'C30W\``(`X.>/_2Q@`0>@```,L>!MZ?!0!@D$-
M\/]+>1M[?`@!@$$``*`X]O^;.'C30W\-Y_]+&`!!Z`8`H#A0`8$X>--#?YG@
M_TL8`$'H4`$A.2Q,0'W^_R(]F!PI.0H`*3DL3"!]$5`I?;``@D!4`2$Y+$Y`
M??[_(CVF'"DY+$X@?5!0R7\``!XLH`""0,[_FS@``*`X>--#?U@!83NAYO]+
M&`!!Z"@`H#AXVV1_>--#?RW@_TL8`$'H_O^"/'B[Z'Z``<&;>-MG?WC+)G]X
MZZ5_FMV$.'C[XW^%X_]+&`!!Z'CKHW^9X/]+&`!!Z'CC@W]X^^1_9?#_2WC[
MXW\)^O]+D/O_2P``>^@Q]/]+>1MZ?#S^@D`T_O]+]`,I?1!12GUX4SY]8/__
M2_[_@CS^_V(\UMR$.&G<8S@A\/]+_O_"/[?=WCNYX/]+&`!!Z/[_@CQXN^A^
M>,LF?WCKI7]X&V=\J=V$.'C[XW_UXO]+&`!!Z,`!@#AX^^-_1>7_2Q@`0>C_
M_P,L7/^"0%7B_TL8`$'H```C@1$`"2Q(_X)`8>#_2Q@`0>@!`!@[>+OI?K0'
M"']XRR9_>!MG?'CKI7]X\\1_>/OC?YGB_TL8`$'HI/__2^`!(3AX^^-_0!P`
M2``````````!@`D```(`3#ST04(XI@((?````&!@@"+I_O]B/!1J*7U-W&,X
M\1L`2('_(?@``"GIL`!)B;$`29G=ZO]+```C+!P`@D$``".),0`)+!``@D`!
M`".)```)+`@`@D'1]O]+````8/[_@CQ@@.+K`P#`.!1J_W\!`*`XR-V$.```
M?^@9X/]+&`!!Z'D;?GQ``()!$``^Z0``?^C^_Z(\RMVE.```B>AUWO]+&`!!
MZ!``/ND``(GH#``D@4``*740`()!``!_Z)7?_TL8`$'H````8/[_@CQ@@.+K
M`P#`.!1J_W\!`*`XS]V$.```?^BMW_]+&`!!Z'D;?7Q@`()!_O]B/!O<8S@1
MZO]+>1ME?!P`@D$0`#WI``!_Z```B>C]W?]+&`!!Z#0``$@U\?]+$``]Z7D;
M?GP``'_HM`""00``B>AX\\5_U=W_2Q@`0>AX\\-_2=[_2Q@`0>@```!@_O^"
M/&"`XNL!`*`X%&K_?]'=A#@``-_K>//#?V'?_TL8`$'H_O^B/.;=I3AX&V1\
M>//#?XG=_TL8`$'H```_Z0``0#G^_V(\$MQC.+$`29EIZ?]+````8```(RS(
M@6+X1`""0````&#`@6+H'?C_2P```&```",LR(%B^"@`@D#^_V(\[-UC.!7?
M_TL8`$'H````8,"!0ND``(GH``"JZ"#__TL```!@P`&`.,B!8NC-XO]+&`!!
MZ`$`(SEX&V9\`0`)*"P`@4`1``,L)`""00```&#`@2+IR(&BZ/[_8CP-WF,X
M``")Z+7>_TL8`$'H@``A./P9`$@``````````8`#```"`$P\F#]".*8""'SP
M_\'[^/_A^W@;?WP0``'XD?\A^''S_TL9\_]+>!M^?.'U_TL```,L4`""00``
M/RQ(`()!```_B0``"2P\`()!_O^"/'CSPW_TW(0XP=[_2Q@`0>@`&#Y\(`""
M0'``(3AX^^-_$``!Z/#_P>OX_^'KI@,(?.3I_TMP`"$X?!D`2``````````!
M@`(```(`3#P`/T(XI@((?#@`PS@!&0!((?TA^/"/+>FH`B'Y```@.0@`(#FF
M`RE]*``!.2PT('T``$;I$``(.0@`QC@@`"EY(@!'>?#_*/D@PDEY($9*>2X$
M*55X4RE]*,#J>'A3*7T>0N=4>#LI??C_*/G`_P!"0``@.2```3FF`RE]<``H
MZ4@`Z.@8`$CI>#HI?7A2*7T)`$CI>%(I?:0/*GG"#REY>$M)?2``*7F``"CY
MT/\`0@``8^D@`(/H$`#CZ!@`P^@(`*/H,`#AZS@`P>O"+FEYI"YH>7A+"'TH
M`"'I@O"J>"``"'F"6O\_F7G_.X):WC^"6BD]%#+_?YEY*3F9>=X[%"(I?10Z
MWG\42@A]>#+I?#@H*7UX,BE]%$H(?63PJ7AX4RE](``=>2``('EX`NI\.%A*
M?7@Z2GT4^DI]R"X?>>(N"'EX0^A_@O!_>11"2GUD\&AY>/L(?2``6GEX0BE]
M(``?>3CH*7UX`BE]%/(I?<@N7GGB+DIY>%/*?Q12*7UD\*I[@O"]>R``.WEX
MZTI]0`"AZWA2"'T@`%YY.-`(?8):O3]X^@A]F7F].Q0"O7_(+B!YXBXI>13J
M"'UX2PE\%$H(?63P27N"\%I[(``<>7C3*7UX2D!]2`!!Z2``/7DXV`!\>/(`
M?():2CV9>4HY%/I*?112`'S(+@IYXBX(>7A#2GT44@!\9/!J>X+P>WL@`!IX
M>-M*?7A2*'U0`"'I(`!?>3C@"'UXZ@A]@EHI/9EY*3D4\BE]%$H(?<@N"7CB
M+@!X>`,I?11*"'UD\(E[@O"<>R``&WEXXRE]>$I`?5@`0>D@`#YY.-``?'CZ
M`'R"6DH]F7E*.13J2GT44@!\R"X*>>(N"'EX0TI]%%(`?&3P2GN"\%I[(``<
M>'C32GUX4BA]8``AZ2``77DXV`A]>/((?8):*3V9>2DY%/HI?11*"'W(+@EX
MXBX`>'@#*7T42@A]9/!I>X+P>WL@`!IY>-LI?7A*0'UH`$'I(``_>3C@`'QX
MZ@!\@EI*/9EY2CD4\DI]%%(`?,@N"GGB+@AY>$-*?112`'QD\(I[@O"<>R``
M&WAXXTI]>%(H?7``(>D@`%YY.-`(?7CZ"'V"6BD]F7DI.13J*7T42@A]R"X)
M>.(N`'AX`RE]%$H(?63P27N"\%I[(``<>7C3*7UX2D!]>`!!Z2``/7DXV`!\
M>/(`?():2CV9>4HY%/I*?112`'S(+@IYXBX(>7A#2GT44@!\9/!J>X+P>WL@
M`!IX>-M*?7A2*'V``"'I(`!?>3C@"'UXZ@A]@EHI/9EY*3D4\BE]%$H(?<@N
M"7CB+@!X>`,I?11*"'UD\(E[@O"<>R``&WEXXRE]>$I`?8@`0>D@`#YY.-``
M?'CZ`'R"6DH]F7E*.13J2GT44@!\R"X*>>(N"'EX0TI]%%(`?&3P2GN"\%I[
M(``<>'C32GUX4BA]D``AZ2``77DXV`A]>/((?8):*3V9>2DY%/HI?11*"'W(
M+@EXXBX`>'@#*7T42@A]9/!I>X+P>WL@`!IY>-LI?7A*0'V8`$'I(``_>3C@
M`'QXZ@!\@EI*/9EY2CD4\DI]%%(`?,@N"GGB+@AY>$-*?112`'QD\(I[@O"<
M>R``&WAXXTI]>%(H?:``(>D@`%YY.-`(?7CZ"'V"6BD]F7DI.13J*7VH`*'K
M%$H(?<@N"7CB+@!X>`,I?8):O3\42@A]9/!)>X+P6GN9>;T[>-,I?2``''EX
M2DI]%/J]?SC82GW(+A]Y>/)*?>(N"'EX0^A_%.I*?11"2GUD\&A[@O![>R``
M('EXVPA]L`!AZR``77EX0BE](``?>3C@*7V"6GL_>`(I?9EY>SL4\GM_R"Y>
M>>(N2GD4VBE]>%/*?Q12*7UD\(I[@O"<>R``.WEXXTI]N`"!ZWA2"'T@`%YY
M..@(?8):G#]X^@A]F7F<.Q0"G'_B+B!Y*"@I>13B"'UX`RE]9/"@>X+PO7L4
M2@A]>.L`?&3P?'MX`DE]P`!!Z3C8*7V"\'M[>/(I?7C;G'^"6DH]F7E*.13Z
M2GWB+A]Y%%(I?2@H"GEX^TI]>.(??!12*7W(`$'I>$+_?R``_WL@``!XB/`]
M>=IN2CVAZTHY%/)*?>(N/GD44O]_*"@J>7CS2GV(\!YY%%+_?]``0>FB\`AY
M>$/>?WCRB'\@`)Q[VFY*/7A*"'VAZTHY(``(>10"2GWB+N![%$)*?2@HZ'MX
M`PA]HO`I>11""GS8`$'I>$N]?WCJR7_B+@AX>/HI?2``WGO:;DH](``I>:'K
M2CD4XDI]B/#\>Q1*2GTH*`EX>$,I?:+PZ'L42BI]X`!!Z7A#G']XXJA_XBX_
M>7@""'T@`+U[VFY*/2``"'FAZTHY%/)*?8CP'G@40DI]*"@H>7C["'VB\`!X
M%$(*?>@`0>EX`]Y_>/*`?^(N'WEX2@!\(`"<>]IN2CT@``!XH>M*.13J2GV(
M\#UYHO`I>10"2GUX2[U_\``AZ2@H`'EX^P!\%`+J?WCJRG_:;BD]>$)*?:'K
M*3D@`$IY%.(I?>(NX'L44BE]*"CJ>W@#2GV(\!QY%%()?/@`(>FB\`AY>$.<
M?R``WGMXXJI_XBX(>-IN*3UX^DI]H>LI.2``2GD4\BE]B/#^>Q12*7TH*`IX
M>$-*?2``O7L44@E]``$AZ:+PZGMX4]Y_XBX?>7CRBG\@`)Q[VFXI/7@"2GVA
MZRDY(`!*>13J*7V(\!UX%%(I?2@H"GEX^TI]HO``>!1227T(`2'I>`.]?WCJ
MP'_B+E]Y>$(`?"``WGO:;BD](```>*'K*3D4XBE]%`(I?2@H0'EX^P!\B/`?
M>10""7P0`2'IHO`(>7A#_W]X^JA_(`"]>]IN*3UX4@A]H>LI.2``"'D4\BE]
MXBX>>!1"*7TH*`AX>/,(?8CP7GD40@E]&`$AZ:+P2GEX4]Y_>/+J?R``_WO:
M;BD]>`)*?:'K*3D@`$IY%.HI?>(N'7D44BE]*"@*>7CK2GV(\!UX%%))?2`!
M(>FB\`!X>`.]?WCJP'\@`-Y[VFXI/7A"`'RAZRDY(```>!3Z*7WB+E]Y%`(I
M?2@H0'EX^P!\B/`?>10""7PH`2'IHO`(>7A#_W]X^JA_(`"]>]IN*3UX4@A]
MH>LI.2``"'D4\BE]XBX>>!1"*7TH*`AX>/,(?8CP7GD40@E],`$AZ:+P2GEX
M4]Y_>/+J?R``_WO:;BD]>`)*?:'K*3D@`$IY%.HI?>(N'7D44BE]*"@*>7CK
M2GV(\!UX%%))?3@!(>FB\`!X>`.]?WCJP'\@`-Y[VFXI/7A"`'RAZRDY(```
M>!3Z*7WB+E]Y%`(I?2@H0'EX^P!\B/`?>10""7Q``2'IHO`(>7A#_W^(\!MX
M>/JH?R``O7O:;BD]>%((?:'K*3D@``AY%/(I?>(N'G@40BE]*"@(>'CS"'V(
M\%YY%$()?4@!(>FB\$IY>%/>?WCRZG\@`/][VFXI/7@"2GVAZRDY(`!*>13J
M*7WB+AUY%%(I?2@H"GEXZTI]HO``>!1227U0`2'I>`-[?WC:P'\@`-Y[>$(`
M?(CP3'G:;BD](```>*'K*3D4^BE]XBY?>10"*7TH*$!Y>/L`?(CP'WD4`HE_
M6`$AZ:+P"'EX0_]_XBZ(>]IN*3VAZPDX>/II?WA2*7T4\@!\(``I>:+P2GD4
M2@!\R"Z)>WA#*7UX4XQ]%$H`?&`!(>D@`'M[(``=>(CPB'L@`)YYVFY)/7AB
MZ7]XXBE]H>M*.13:2GT@`"EY:`%AZQ1*2GW(+@EXXBX`>"``_WMX`RE]%$I*
M?:+PB7MX2PA]&X\@/=R\*6$@`!QY(``I>7A#@'T4VFE_..",?3CH`'P4^OM_
M>&,`?"``6GD4^@!\R"Y?>>(N2GEX4^I_9/"_>X+PO7L44D!]>.O_?R``3'EX
M^PA]..#@?SC0"'T@`/U[>`,(?7`!`>@4`@E\%/(`?!0""'W(+D!YXBY*>7A3
M"GP44@A]9/!*>X+P6GL@`!MY>--*?2``7GEX4^!_.&``?#CP_W]X^P!\>`'A
MZQ3ZZ7\4XO]_%/H`?,@N'WGB+@AY>$/H?V3PGWF"\(QY%$(`?'AC_W\@`!IX
M>/M(?3CPZG\XV`A](`#\>WA3"'V``4'I%%))?13J2GT44@A]R"X*>.(N`'AX
M`TI]%%((?63P:GN"\'M[(``,>7C;2GT@`%UY>%/@?SC0`'PXZ/]_>/L`?(@!
MX>L4^NE_%/+_?Q3Z`'S(+A]YXBX(>7A#Z']D\%][@O!:>Q1"`'QXT_]_(``;
M>'C[2'TXZ.I_.&`(?2``_GMX4PA]D`%!Z11227T4XDI]%%((?<@N"GCB+@!X
M>`-*?112"'UD\(IY@O",>2``&GEX8TI](`!<>7A3X'\XV`!\..#_?WC[`'R8
M`>'K%/KI?Q3J_W\4^@!\R"X?>>(N"'EX0^A_9/!_>X+P>WL40@!\>-O_?R``
M#'AX^TA]..#J?SC0"'T@`/U[>%,(?:`!0>D44DE]%/)*?112"'W(+@IXXBX`
M>'@#2GT44@A]9/!*>X+P6GL@`!MY>--*?2``7GEX4^!_.&``?#CP_W]X^P!\
MJ`'AZQ3ZZ7\4XO]_%/H`?,@N'WGB+@AY>$/H?V3PGWF"\(QY%$(`?'AC_W\@
M`!IX>/M(?3CPZG\XV`A](`#\>WA3"'VP`4'I%%))?13J2GT44@A]R"X*>.(N
M`'AX`TI]%%((?63P:GN"\'M[(``,>7C;2GT@`%UY>%/@?SC0`'PXZ/]_>/L`
M?+@!X>L4^NE_%/+_?Q3Z`'S(+A]YXBX(>7A#Z']D\%][@O!:>Q1"`'QXT_]_
M(``;>'C[2'TXZ.I_.&`(?2``_GMX4PA]P`%!Z11227T4XDI]%%((?<@N"GCB
M+@!X>`-*?112"'UD\(IY@O",>2``&GEX8TI](`!<>7A3X'\XV`!\..#_?WC[
M`'S(`>'K%/KI?Q3J_W\4^@!\R"X?>>(N"'EX0^A_9/!_>X+P>WL40@!\>-O_
M?R``#'AX^TA]..#J?SC0"'T@`/U[>%,(?=`!0>D44DE]%/)*?112"'W(+@IX
MXBX`>'@#2GT44@A]9/!*>X+P6GL@`!MY>--*?2``7GEX4^!_.&``?#CP_W]X
M^P!\V`'AZQ3ZZ7\4XO]_%/H`?,@N'WGB+@AY>$/H?V3PGWF"\(QY%$(`?'AC
M_W\@`!IX>/M(?3CPZG\XV`A](`#\>WA3"'W@`4'I%%))?13J2GT44@A]R"X*
M>.(N`'AX`TI]%%((?63P:GN"\'M[(``,>7C;2GT@`%UY>%/@?SC0`'PXZ/]_
M>/L`?.@!X>L4^NE_%/+_?V3P7GN"\%I[%/H`?'C3WG_(+A]YXBX(>7CS2GUX
M0^A_.&!*?11"`'TXZ,!_>`-*??`!`>@@`!MY(`#?>Q0""7P4X@!\%`)*?<@N
M`'GB+@AY>$,(?!1"2GUD\(AY@O",>2``7'EX8PA](``,>7A#P'\XV`!\.&#>
M?WCS`'SX`<'K%/+)?Q3JWG\4\@!\XBY>>2@H2GEX\TI]%%(`?&3P:GN"\'M[
M>-M*?7A3"'TX8%U]..`(?2``7GEXZPA]``*AZQ3J*7T4^BE]XBX?>!1*"'TH
M*`EX>/LI?63PGWL42@A]@O")>WA+_'\(`N'K8LH@/=;!*6%XXDI](``I>7@"
M2GT4^NE_(`!*>11B_W_B+AUY%/I*?2@H'WEXZ_]_B/`=>!3Z2GVB\`!X$`+A
MZW@#O7]XZH!_(`"<>WA"`'P4^NE_%/+_?R```'CB+EYY%/H`?"@H7WEX\_]_
MB/`>>:+P"'D4^@!\>$/>?Q@"`>EX\K]_(`"]>WA2_W\40@E](`#_>Q3B"'WB
M+AQX%/H(?2@H'WAXX_]_%/H(?8CP7WFB\$IYXBX<>7A3_W\@`D'I%%))?13J
M2GUX^MU_>`*]?R``WGL@`+U[%.I*?2@H'7EXX[U_%.I*?8CP'7BB\`!XXBY<
M>7@#O7\H`@'H%`()?!3R`'QXZOY_>$+>?R``_WL@`-Y[%/(`?"@H7GEXX]Y_
M%/(`?(CP'GFB\`AYXBX<>'A#WG\P`@'I%$()?13Z"'UX\K]_>%+_?R``O7L@
M`/][%/H(?2@H'WAXX_]_%/H(?8CP7WFB\$IYXBX<>7A3_W\X`D'I%%))?13J
M2GUX^MU_>`*]?R``WGL@`+U[%.I*?2@H'7EXX[U_%.I*?8CP'7BB\`!XXBY<
M>7@#O7]``@'H%`()?!3R`'QXZOY_>$+>?R``_WL@`-Y[%/(`?"@H7GEXX]Y_
M%/(`?(CP'GFB\`AYXBX<>'A#WG](`@'I%$()?13Z"'UX\K]_>%+_?R``O7L@
M`/][%/H(?2@H'WAXX_]_%/H(?8CP7WFB\$IYXBX<>7A3_W]0`D'I%%))?13J
M2GUX^MU_>`*]?R``WGL@`+U[%.I*?2@H'7EXX[U_%.I*?8CP'7BB\`!XXBY<
M>7@#O7]8`@'H%`()?!3R`'QXZOY_>$+>?R``_WL@`-Y[%/(`?"@H7GEXX]Y_
M%/(`?(CP'GFB\`AYXBX<>'A#WG]@`@'I%$()?13Z"'UX\K]_>%+_?R``O7L@
M`/][%/H(?2@H'WAXX_]_%/H(?8CP7WFB\$IYXBX<>7A3_W]H`D'I%%))?13J
M2GUX^MU_>`*]?R``WGL@`+U[%.I*?2@H'7EXX[U_%.I*?8CP'7BB\`!XXBY<
M>7@#O7]P`@'H%`()?!3R`'QXZOY_>$+>?R``_WL@`-Y[%/(`?"@H7GEXX]Y_
M%/(`?(CP'GFB\`AYXBX<>'A#WG]X`@'I%$()?13Z"'UX\K]_>%+_?R``O7L@
M`/][%/H(?2@H'WAXX_]_%/H(?8CP7WFB\$IYXBX<>7A3_W^``D'I%%))?13J
M2GUX^MU_>`*]?R``WGL@`+U[%.I*?2@H'7EXX[U_B/`<>*+P`'@4ZDI]>`.<
M?X@"`>CB+EUY%`()?!3R`'QXXOY_>$+>?R``_WL@`-Y[%/(`?"@H7GEXZ]Y_
MB/`=>:+P"'D4\@!\>$.]?Y`"`>GB+AYX%$()?13Z"'UXZI]_>%+_?R``G'L@
M`/][%/H(?2@H'WAX\_]_B/!>>:+P2GD4^NA_>%/>?Y@"0>EX\JA_(`"]>W@"
M"'T44DE](``(>13B2GWB+OQ[%$)*?<@NZ'MXXPA]%$)*?8CP"'BB\`!X>`,(
M?:`"`>@4`BE]XBY`>11:*7UX0LM_>/IK?13J*7T@`&MY%#((?11:*7W(+DMY
M%"I*?7@#:WT@`$IY%%HI?2``*7FB\.5["`!#^8CPZGL@``AY>"M*?0``(_D4
M(CY]%#I*?2``*7D8``/Y(`!*>2``(_D0`$/YJ`)!Z?"/+>EY2DI]```@.0P`
M@D&1RO]+&`!!Z.`"(3C,`P!(``````````&`!@```@!,/'0I0CBF`@A\@`!@
M.!```?CA_R'X?<O_2Q@`0>A%9T`](``A.`$C2F$``$/YS>]`/8FK2F$@`$IY
M"`!#^;J80#W^W$IA(`!*>1``0_DR$$`]=E1*81@`0_G2PT`]\.%*82``2GD@
M`$/Y``!`.7@`0Y$H`$/Y,`!#^1```>BF`PA\(`"`3@`````````!@`````(`
M3#S@*$(XI@((?"0?J7C=`@!(H?\A^'@;?WQX(YE\>"N^?"@`0^D44BE](``I
M>4!(*GP0`(%`,`!#Z0$`2CDP`$/Y>`!_@"@`/_DP`#_I0A_*>S@`GSL```,L
M%%(I?3``/_E8`()!0`"C(P#P'7P(`(%`>//=?[0'NW^T!V-\>-ME?WC+)'\4
M&GQ\-<7_2Q@`0>AX`#^!%$H]?4``"2QX`#^11`""0%#PO7]X^^-_M`>^?Q3:
M.7\QZ?]+$`"@.R``8#LP`$`[/P`>+"0`@4%X\\5_>,LD?WCC@W_EQ/]+&`!!
MZ'@`WY-@`"$X.`(`2)C.0'V8[GE]P/_>.WC[XW^8WIE]F-89?+0'WG]``#D[
MF.=`?9CO?'V8WYQ]F-<<?,GH_TND__]+``````````&`!P```@!,/*PG0CBF
M`@A\*``D.8#_0#FM`0!(L?\A^#@`I#MX&WY\>".??"Q,@'\P`"0Y+$Q@?R@`
M).F^[BE5`0"I.+0'*7TX``4LM`>C?*Y)77T4&GU\-`&!0$``I2```(`XM`>E
M?(G'_TL8`$'H>/OC?T7H_TLX`*`X``"`.'CKHW]MQ_]+&`!!Z'``?Y-T`)^3
M>/OC?R'H_TL``#_I>/OC?P)&*7D``#Z9```_Z0*$*7D!`#Z9```_Z0+"*7D"
M`#Z9```_Z0,`/ID(`#_I`D8I>00`/ID(`#_I`H0I>04`/ID(`#_I`L(I>08`
M/ID(`#_I!P`^F1``/^D"1BEY"``^F1``/^D"A"EY"0`^F1``/^D"PBEY"@`^
MF1``/^D+`#Z9&``_Z0)&*7D,`#Z9&``_Z0*$*7D-`#Z9&``_Z0+"*7D.`#Z9
M&``_Z0\`/ID@`#_I`D8I>1``/ID@`#_I`H0I>1$`/ID@`#_I`L(I>1(`/ID@
M`#_I$P`^F=7#_TL8`$'H4``A.'0``$@X`*4@``"`.+0'I7SL_O]+````````
M``&`!0``H/^!^JC_H?JP_\'ZN/_A^L#_`?O(_R'[T/]!^]C_8?O@_X'[Z/^A
M^_#_P?OX_^'[$``!^"``@$Z@_X'JJ/^AZK#_P>JX_^'JP/\!Z\C_(>O0_T'K
MV/]AZ^#_@>L0``'HZ/^AZZ8#"'SP_\'K^/_AZR``@$[P_\'K$``!Z/C_X>NF
M`PA\(`"`3IBC`0``````I@((?`4`GT*F`FA]I@,(?/#_"^A08(M]%%I@?=3_
M##@``(OI@O``>*8#B7T(`&OI(`2`3LS__TO(__]+Q/__2\#__TN\__]+N/__
M2[3__TNP__]+K/__2ZC__TND__]+H/__2YS__TN8__]+E/__2Y#__TN,__]+
MB/__2X3__TN`__]+?/__2WC__TMT__]+</__2VS__TMH__]+9/__2V#__TM<
M__]+6/__2U3__TM0__]+3/__2TC__TM$__]+0/__2SS__TLX__]+-/__2S#_
M_TLL__]+*/__2R3__TL@__]+'/__2QC__TL4__]+$/__2PS__TL(__]+!/__
M2P#__TO\_O]+^/[_2_3^_TOP_O]+[/[_2P(`3#Q@)$(XI@((?!```?CA_R'X
M(``A.!```>BF`PA\(`"`3@`````N+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I
M+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`)7,Z('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A
M;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!P87)L`"YP87(`)7,E<V-A8VAE
M+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P
M`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4W`%5N86)L92!T;R!C<F5A=&4@
M8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`55-%
M4@!54T523D%-10!414U01$E2`%1-4``O=&UP`&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?
M34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*
M0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S
M971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`]
M(#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?
M<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V
M-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S
M(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@
M(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI
M;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L
M("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H
M*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E
M='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U
M<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@
M)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E
M<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER
M("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN
M,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T
M;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@
M)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN
M(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R
M7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF
M:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE
M)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D
M8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G
M;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ
M<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D
M<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*
M;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?
M1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@
M9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E
M(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA
M9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O
M<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!
M4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]
M"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T
M:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N
M92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD[
M"FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O
M=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@
M)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O
M;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A
M<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U
M;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T
M(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^
M<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M
M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F
M:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H
M.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D
M=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S
M*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B
M)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;
M0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q
M("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@
M*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L
M($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I
M92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ
M+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY
M("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO
M="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L
M;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I
M;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I
M;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D
M97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O
M(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D
M97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z
M("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H
M($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L
M:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@
M*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y
M?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I
M<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL
M87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2![
M"FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG
M($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968[
M"F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T
M:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\
M96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T
M96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@
M*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]
M"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]
M($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C
M='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F
M<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A
M73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A
M:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J
M(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N
M+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN
M9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!0
M05(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![
M(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@
M>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H
M:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H
M.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U
M:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*
M?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP
M(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6
M>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@
M*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E
M<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I
M;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE
M;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]
M"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?
M9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%
M04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@
M;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O
M<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`[
M"FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S
M"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C
M86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M
M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M
M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C
M86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*
M)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S
M=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F
M:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT
M<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T
M96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]
M7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?
M(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U
M8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN
M="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS
M=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/
M4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%
M3D1?7PH``'!E<FQX<VDN8P``0T%#2$4``````1L#.^`````;````%(?__\P$
M``"8B___$`$``&B,__](`0``R(S__V@!``!LC?__D`$``!B.__^X`0``E(__
M__`!``#(D/__(`(``.22__]<`@``1)/__WP"``"PD___H`(``)"4___,`@``
MJ)3__^`"``#PEO__,`,``$27__]4`P``@)C__X`#``#`F?__M`,``"B:___4
M`P``=)K___0#```XF___*`0``&"A__]H!```O*/__Y@$``!4I/__\`0``."Y
M__\H!0``=+K__T@%``"HN___A`4``-R]___X````$``````````!>E(`!'A!
M`1L,`0`4````&````-R\__\8`0```$()00!"!D$T````,````("*___0````
M`$,)00!!F@:;!9P$G0.>`I\!$4%^0@Y02PH.`$+?WMW<V]H&00L``!P```!H
M````&(O__V``````10YP$4%^30X`0@9!````)````(@```!8B___I`````!%
M"4$`G@*?`4,.@`$107Y=#@!!W]X&020```"P````U(O__ZP`````1`E!`)\!
M0P[0`1%!?F`.`$'?!D$````T````V````%B,__]\`0```$,)00!!F@:;!9P$
MG0.>`I\!$4%^00ZP`@)6#@!!W][=W-O:!D$``"P````0`0``G(W__S0!````
M1PE!`$&<!)T#G@*?`1%!?D8.T(`$>PX`0=_>W=P&03@```!``0``H([__QP"
M````0PE!`$&9!YH&FP6<!)T#G@*?`1%!?D$.L`$"?@X`0=_>W=S;VMD&00``
M`!P```!\`0``@)#__V``````3@X@$4%^1`X`0@9!````(````)P!``#`D/__
M;`````!$"4$`GP%%#C`107Y.#@!!WP9!*````,`!```(D?__X`````!#"4$`
M09T#G@*?`1%!?D$.H$%N#@!"W][=!D$0````[`$``+R1__\8`````````$P`
M`````@``P)'__T@"````10E!`!%(?T&4#)4+E@J7"9@(F0>:!IL%G`2=`YX"
MGP$107Y!#N`B`H0.`$3?WMW<V]K9V-?6U=0&009(````(````%`"``"XD___
M5`````!%"4$`GP%##C`107Y)#@!!WP9!*````'0"``#HD___/`$```!%"4$`
MG@*?`4,.P"`107X"0PX`0=_>!D$````P````H`(``/B4__]``0```$4)00!!
MG`2=`YX"GP$107Y!#H`!?@H.`$'?WMW<!D$+````'````-0"```$EO__:```
M``!'#F`107Y,#@!#!D$````<````]`(``$R6__],`````$4.(!%!?D@.`$(&
M00```#`````4`P``>);__\0`````0PE!`$&<!)T#G@*?`1%!?D$.@`%."@X`
M0=_>W=P&00L````\````2`,```B7__\H!@```$0)00!!EPF8")D'F@:;!9P$
MG0.>`I\!$4%^00[@`P-_`0X`0M_>W=S;VMG8UP9!+````(@#``#PG/__7`(`
M``!("4$`09T#G@*?`1%!?D$.@`$"B0X`0=_>W09!````,````+@#```<G___
MF`````!%"4$`G@*?`4,.<!%!?E,*#@!%!D'?WD$+00X`0=_>!D$``"````#L
M`P``0(+__SP"````1@Z0`1%!?I\!`H`*#@!"WP9!"S0````0!```7)___XP5
M````1`E!`$&:!IL%G`2=`YX"GP$107Y!#N`%`UD%#@!!W][=W-O:!D$`'```
M`$@$``"PM/__E`````!&#B`107Y$#@!7!D$````X````:`0``"2U__\T`0``
M`$0)00!!F0>:!IL%G`2=`YX"GP$107Y!#F!U"@X`0=_>W=S;VMD&00L````P
M````I`0``!RV__^D`0```$4)00!!FP6<!)T#G@*?`1%!?D$.4`):"@X`0=_>
MW=S;!D$+````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#P)@```````&`F`````````0````````#4
M`@````````$`````````WP(````````/`````````$,%````````#```````
M``!H&P````````T`````````H%H````````9`````````!C[`0``````&P``
M```````(`````````!H`````````(/L!```````<``````````@`````````
M]?[_;P`````@`@````````4`````````4`X````````&`````````/@"````
M````"@````````!A!0````````L`````````&``````````5````````````
M`````````P`````````H_0$```````(`````````6`4````````4````````
M``<`````````%P`````````0%@```````````'``````G%D````````#``!P
M````````````````!P````````"X$P````````@`````````6`(````````)
M`````````!@`````````&````````````````````/O__V\``````0``"```
M``#Y__]O``````T`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````"E!!4BYP;0H``````````&Y=````
M````R5H``````````````````*I;````````HUL```````!B70```````,!;
M````````:ET``````````````````%1=````````65T`````````````````
M`'-=````````1T-#.B`H06QP:6YE(#$R+C(N,5]G:70R,#(R,#DR-"UR-"D@
M,3(N,BXQ(#(P,C(P.3(T```N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E
M>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`````````````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M``````````(``````````@```````!X````````````````````!````````
M````````````$P```/;__V\"`````````"`"````````(`(```````#8````
M``````,`````````"````````````````````!T````+`````@````````#X
M`@```````/@"````````6`L````````$````&P````@`````````&```````
M```E`````P````(`````````4`X```````!0#@```````&$%````````````
M```````!````````````````````+0````0````"`````````+@3````````
MN!,```````!8`@````````,`````````"``````````8`````````#<````$
M````0@`````````0%@```````!`6````````6`4````````#````$`````@`
M````````&`````````!!`````0````8`````````:!L```````!H&P``````
M`"0````````````````````$````````````````````1P````$````&````
M`````*`;````````H!L`````````/P``````````````````(```````````
M`````````$T````!````!@````````"@6@```````*!:````````)```````
M``````````````0```````````````````!3`````0````(`````````R%H`
M``````#(6@```````.%````````````````````(````````````````````
M6P````$````"`````````*R;````````K)L```````#D````````````````
M````!````````````````````&D````!`````@````````"0G````````)"<
M````````V`0```````````````````0```````````````````!S````#@``
M``,`````````&/L!```````8^P````````@````````````````````(````
M``````@`````````?P````\````#`````````"#[`0``````(/L````````(
M````````````````````"``````````(`````````(L````&`````P``````
M```H^P$``````"C[``````````(````````$``````````@`````````$```
M```````\````"`````,`````````*/T!```````H_0```````-@!````````
M```````````(``````````@`````````E`````$````#``````````#_`0``
M`````/\```````!H``````````````````````$````````(`````````)D`
M```!`````P````````````(``````````0``````@```````````````````
M``@```````````````````"?````"`````,`````````@``"``````"```$`
M`````%@````````````````````(````````````````````I`````$````P
M````````````````````@``!```````T`````````````````````0``````
M```!``````````$````#`````````````````````````+0``0``````K0``
=``````````````````$`````````````````````
